@@ -4,19 +4,21 @@ from enum import Enum, unique
 class Colors(Enum):
     GREEN = 'green'
     RED = 'red'
+    MAGENTA = 'magenta'
 
 
 @unique
 class RunCode(Enum):
     DEBUG = 0
     DAILY = 1
-    MONTHLY = 2
-    ONCE = 3
+    WEEKLY = 3
+    MONTHLY = 4
+    ONCE = 5
 
 
 @unique
 class Permission(Enum):
     ADMIN = 0
-    OUTPOST = 1
-    EXECUTIVE = 2
+    EXECUTIVE = 1
+    OPERATOR = 2
     SERVICE = 3
